vi3o - VIdeo and Image IO
=========================

Utility for loading/saving/displaying video and images. It gives random
access to mjpg (in http multipart format) and H264 (in .mkv format) video
frames. For recordings origination from Axis cameras the camera system
time at the time of capture is provided as timestamp for each frame.

Further details are provided in the `Documentation`_

.. _`Documentation`: https://vi3o.readthedocs.org
